@@ -19,7 +19,7 @@ def df_dimension(data):
     """
     row_count, col_count = data.shape
     print(
-        '\033[1m', f'Le jeu de données contient {row_count} lignes et {col_count} colonnes.', '\033[0m')
+        '\033[1m', f'Le jeu de données contient {row_count} lignes et {col_count} variables.', '\033[0m')
 
 def df_dtypes_count(data):
     """Retourne les dtypes du dataFrame ainsi que le décompte.
@@ -30,7 +30,7 @@ def df_dtypes_count(data):
     print(data.dtypes.value_counts())
 
 def df_columns_breakdown(data):
-    """Retourne la liste des colonnes du dataFrame, classées par dtype.
+    """Retourne la liste des variables du dataFrame, classées par dtype.
 
     Keyword arguments:
     data -- le dataFrame
@@ -96,14 +96,14 @@ def delete_nanfilled_cols(data, cutoff=.90, exclude=False, inplace=False):
             if elt in cols_to_delete:
                 cols_to_delete[elt] = False
     print(
-        '\033[1m', f'Avec un cutoff à {cutoff*100}% de valeurs manquantes maximum par colonnes, {cols_to_delete.sum()} colonnes {"on été supprimées." if inplace else "devrait être supprimées."} :')
+        '\033[1m', f'Avec un cutoff à {cutoff*100}% de valeurs manquantes maximum par variables, {cols_to_delete.sum()} variables {"on été supprimées." if inplace else "devrait être supprimées."} :')
     print('\033[0m')
     print(cols_to_delete.index[cols_to_delete == True].tolist())
     print('')
 
     remaining_cols = cols_to_delete.index[cols_to_delete == False].tolist()
     print(
-        '\033[1m', f'{len(remaining_cols)} colonnes restantes :\n', '\033[0m')
+        '\033[1m', f'{len(remaining_cols)} variables restantes :\n', '\033[0m')
     print(remaining_cols)
 
     if inplace:
@@ -132,11 +132,11 @@ def delete_nanfilled_lines(data, variables=False, inplace=False, count=True):
       return data.dropna(subset=variables, how="all")
 
 def df_description(data, col_count=False, return_only=False):
-    """Description des variables enrichie de 2 colonnes = nombre de nan et % de nan
+    """Description des variables enrichie de 2 variables = nombre de nan et % de nan
     
     Keyword arguments:
     data -- le dataFrame
-    col_count -- le nombre de colonnes avant saut de lignes
+    col_count -- le nombre de variables avant saut de lignes
     """
     if col_count:
         q, mod = divmod(data.shape[1], col_count)
@@ -164,7 +164,7 @@ def df_description(data, col_count=False, return_only=False):
             display(desc)
 
 def df_find_empty_cols(data, inplace=False):
-    """Trouve les colonnes vides et les supprime si demandé.
+    """Trouve les variables vides et les supprime si demandé.
     
     Keyword arguments:
     data -- le dataFrame
@@ -173,13 +173,13 @@ def df_find_empty_cols(data, inplace=False):
     df_count = data.count()
     empty_cols = df_count[df_count == 0]
     print(
-        '\033[1m', f'{len(empty_cols)} colonnes vides {"ont été supprimées" if inplace else ""} :\n ', '\033[0m')
+        '\033[1m', f'{len(empty_cols)} variables vides {"ont été supprimées" if inplace else ""} :\n ', '\033[0m')
     print(', '.join(empty_cols.index))
     if inplace:
         data.drop(empty_cols.index, inplace=True, axis=1)
 
 def df_cols_format(data, to_replace, new_str, inplace=False):
-    """Formattage des noms de colonnes
+    """Formattage des noms de variables
     
     Keyword arguments:
     data -- le dataFrame
@@ -245,7 +245,7 @@ def df_outlier_boxplot(series, title, borne_inf, borne_sup, outlier_inf=False, o
     """ Retourne un boxplot orienté vers la recherche d'outliers avec des bornes inf et sup et des cutoff inf et sup
 
     Args:
-        series (series): la colonne
+        series (series): la variable
         title (string): le titre
         borne_inf (int): la borne inférieure du graphique
         borne_sup (int): la borne supérieure du graphique
@@ -282,7 +282,7 @@ def df_outlier_count(data, col, outlier_inf, outlier_sup):
 
     Args:
         data (dataframe): le dataFrame
-        col (string): la colonne à traiter
+        col (string): la variable à traiter
         outlier_inf (int): la borne inférieure
         outlier_sup (int): la borne supérieure
     """
@@ -313,9 +313,9 @@ def df_plot_distribution(data, feature, xlim=False, ylim=False, boxlim=False):
     Args:
         data (dataframe): le dataFrame
         feature (string): la feature
-        xlim (tuple): limite-range axe x du displot 
-        ylim (tuple): limite-range axe x du displot 
-        blim (tuple): limite-range axe x du boxplot 
+        xlim (float): limite-range axe x du displot 
+        ylim (float): limite-range axe x du displot 
+        boxlim (tuple): limite-range axe x du boxplot 
     """
     df = data[feature].value_counts(normalize=True).sort_index()
 
@@ -367,6 +367,7 @@ def df_plot_distribution(data, feature, xlim=False, ylim=False, boxlim=False):
     plt.subplots_adjust(wspace=0.3)
     plt.show()
 
+
 def shapiro_test(data, feature):
     """ Retourne une présentation des tests de normalité de Shapiro
     
@@ -376,10 +377,11 @@ def shapiro_test(data, feature):
     """
     a = 0.05
     test = stats.shapiro(data[feature])
-    if test.pvalue <= 0.05:
-        return f'La distribution de \033[1m{feature}\033[0m s\'éloigne significativement de la loi Normale. , W= {round(test.statistic,2)}, P value= {round(test.pvalue,2)}\n'
+    if test[1] <= a:
+        print(f'La distribution de \033[1m{feature}\033[0m s\'éloigne significativement de la loi Normale. , W= {round(test[0],2)}, P value= {round(test[1],2)}\n')
     else:
-        return f"La distribution de {feature} \033[4m\033[1ms'approche de la loi normale\033[0m, W= {round(test.statistic,2)}, P value= {round(test.pvalue,2)}.\n"
+        print(f"La distribution de {feature} \033[4m\033[1ms'approche de la loi normale\033[0m, W= {round(test[0],2)}, P value= {round(test[1],2)}.\n")
+
 
 def df_chisquared_table(data, feature1, feature2, alpha: float, displayTable=False):
     """ Retourne une présentation des tests de normalité de Shapiro
@@ -407,6 +409,12 @@ def df_chisquared_table(data, feature1, feature2, alpha: float, displayTable=Fal
     else:
         print('H0 maintenue : il n\'y a pas de dépendance')
 
+def outlier_rejection(X, y,contamin):
+    """This will be our function used to resample our dataset."""
+    model = IsolationForest(max_samples=100,contamination=contamin)
+    model.fit(X)
+    y_pred = model.predict(X)
+    return X[y_pred != -1], y[y_pred != -1]
 ####################################################
 #                                                  #
 #               FROM OpenClassrooms                #
